# MySQL easy

MySQL easy is a tool to augment your database development using MySQL. It gives you more insight into your MySQL database, by providing you an ability to graphically trace code dependencies between MySQL views, stored procedures and tables.

It is also an intelligent code generator. It generates code for you in SQL or in Python based on your table structure and relationships between the table. This tool will help debug larger database applications easily and write code in matter of clicks that you may require few days of effort. 

## SQL code
Sample code that you can use to create a table named user with three columns user_id, last_name and first_name.

```sql
CREATE TABLE `user` (
  `user_id` int(11) NOT NULL AUTO_INCREMENT,
  `first_name` varchar(70) DEFAULT NULL,
  `last_name` varchar(70) DEFAULT NULL,
  PRIMARY KEY (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;
```

## Code generation

Use [MySQLeasy](http://www.mysqleasy.com) to generate code for your table. Once python class for user is generated run it.

## Python code

Following code will insert a new user John Smith. Then search the records with last name Smith. Then update the first name to Mike in the first row. Update the records in database and at the end close the connection.

```python
from mysqleasy.Connection import Connection as Connection
from mysqleasy.Access import Access as Access
connector = "mysqlconnector"
db_config = {'host': 'your_database_host_address', 'user': 'your_database_user_name', 'password': 'your_database_password'}
conn = Connection.create(connector, db_config)
last_row_id = user.insert(conn, first_name = "John", last_name = "Smith")
columns, users = user.search(conn, last_name='Smith')
user_list = [o for o in Access.iter_object(columns, users)]
last_row_id, count_affected = user.insertupdate_multiple(conn, [('Mike', 'Smith', 1)])
conn.commit()
conn.close()
``` 
